@@ -2065,7 +2065,7 @@ TkFinalize(
  * TkFinalizeThread --
  *
  *	Runs our private thread exit handlers and removes itself from Tcl.
- *	This is benificial should we want to protect from dangling pointers
+ *	This is beneficial should we want to protect from dangling pointers
  *	should the Tk shared library be unloaded prior to Tcl which can happen
  *	on Windows should the process be forcefully exiting from an exception
  *	handler.
