@@ -15,19 +15,6 @@
 #include "tkMacOSXPrivate.h"
 #include "tkMacOSXFont.h"
 
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 1080
-#define defaultOrientation kCTFontDefaultOrientation
-#define verticalOrientation kCTFontVerticalOrientation
-#else
-#define defaultOrientation kCTFontOrientationDefault
-#define verticalOrientation kCTFontOrientationVertical
-#endif
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 101100
-#define fixedPitch kCTFontUserFixedPitchFontType
-#else
-#define fixedPitch kCTFontUIFontUserFixedPitch
-#endif
-
 /*
 #ifdef TK_MAC_DEBUG
 #define TK_MAC_DEBUG_FONTS
@@ -104,9 +91,9 @@ static void DrawCharsInContext(Display *display, Drawable drawable, GC gc,
 	int rangeLength, int x, int y, double angle);
 
 @interface NSFont(TKFont)
-- (NSFont *)bestMatchingFontForCharacters:(const UTF16Char *)characters
-	length:(NSUInteger)length attributes:(NSDictionary *)attributes
-	actualCoveredLength:(NSUInteger *)coveredLength;
+- (NSFont *) bestMatchingFontForCharacters: (const UTF16Char *) characters
+	length: (NSUInteger) length attributes: (NSDictionary *) attributes
+	actualCoveredLength: (NSUInteger *) coveredLength;
 @end
 
 #pragma mark -
@@ -210,7 +197,6 @@ FindNSFont(
 	nsFont = [fm convertFont:nsFont toSize:size];
 	nsFont = [fm convertFont:nsFont toHaveTrait:traits];
     }
-    [nsFont retain];
     #undef defaultFont
     return nsFont;
 }
@@ -284,7 +270,7 @@ InitFont(
 	fmPtr->fixed = [nsFont advancementForGlyph:glyphs[0]].width ==
 		[nsFont advancementForGlyph:glyphs[1]].width;
 	bounds = NSRectFromCGRect(CTFontGetBoundingRectsForGlyphs((CTFontRef)
-		nsFont, defaultOrientation, ch, boundingRects, nCh));
+		nsFont, kCTFontDefaultOrientation, ch, boundingRects, nCh));
 	kern = [nsFont advancementForGlyph:glyphs[2]].width -
 		[fontPtr->nsFont advancementForGlyph:glyphs[2]].width;
     }
@@ -307,7 +293,7 @@ InitFont(
 	    [NSNumber numberWithInt:fmPtr->fixed ? 0 : 1],
 		NSLigatureAttributeName,
 	    [NSNumber numberWithDouble:kern], NSKernAttributeName, nil];
-    fontPtr->nsAttributes = [nsAttributes retain];
+            fontPtr->nsAttributes = TkMacOSXMakeUncollectableAndRetain(nsAttributes);
     #undef nCh
 }
 
@@ -372,7 +358,6 @@ TkpFontPkgInit(
     NSFont *nsFont;
     TkFontAttributes fa;
     NSMutableCharacterSet *cs;
-    /* Since we called before TkpInit, we need our own autorelease pool. */
     NSAutoreleasePool *pool = [NSAutoreleasePool new];
 
     /* force this for now */
@@ -397,7 +382,8 @@ TkpFontPkgInit(
 	systemFont++;
     }
     TkInitFontAttributes(&fa);
-    nsFont = (NSFont*) CTFontCreateUIFontForLanguage(fixedPitch, 11, NULL);
+    nsFont = (NSFont*) CTFontCreateUIFontForLanguage(
+	    kCTFontUserFixedPitchFontType, 11, NULL);
     if (nsFont) {
 	GetTkFontAttributesForNSFont(nsFont, &fa);
 	CFRelease(nsFont);
@@ -466,7 +452,7 @@ TkpGetNativeFont(
     ctFont = CTFontCreateUIFontForLanguage(HIThemeGetUIFontType(
 	    themeFontId), 0, NULL);
     if (ctFont) {
-	fontPtr = (MacFont *) ckalloc(sizeof(MacFont));
+	fontPtr = ckalloc(sizeof(MacFont));
 	InitFont((NSFont*) ctFont, NULL, fontPtr);
     }
 
@@ -522,7 +508,7 @@ TkpGetFontFromAttributes(
 
     nsFont = FindNSFont(faPtr->family, traits, weight, points, 0);
     if (!nsFont) {
-	char *const *aliases = TkFontGetAliasList(faPtr->family);
+	const char *const *aliases = TkFontGetAliasList(faPtr->family);
 
 	while (aliases && !nsFont) {
 	    nsFont = FindNSFont(*aliases++, traits, weight, points, 0);
@@ -532,10 +518,10 @@ TkpGetFontFromAttributes(
 	nsFont = FindNSFont(faPtr->family, traits, weight, points, 1);
     }
     if (!nsFont) {
-	Tcl_Panic("Could not determine NSFont from TkFontAttributes");
+	Tcl_Panic("Could not deternmine NSFont from TkFontAttributes");
     }
     if (tkFontPtr == NULL) {
-	fontPtr = (MacFont *) ckalloc(sizeof(MacFont));
+	fontPtr = ckalloc(sizeof(MacFont));
     } else {
 	fontPtr = (MacFont *) tkFontPtr;
 	TkpDeleteFont(tkFontPtr);
@@ -571,8 +557,7 @@ TkpDeleteFont(
 {
     MacFont *fontPtr = (MacFont *) tkFontPtr;
 
-    [fontPtr->nsAttributes release];
-    fontPtr->nsAttributes = NULL;
+    TkMacOSXMakeCollectableAndRelease(fontPtr->nsAttributes);
     CFRelease(fontPtr->nsFont); /* Either a CTFontRef or a CFRetained NSFont */
 }
 
@@ -677,6 +662,7 @@ TkpGetFontAttrsForChar(
 {
     MacFont *fontPtr = (MacFont *) tkfont;
     NSFont *nsFont = fontPtr->nsFont;
+
     *faPtr = fontPtr->font.fa;
     if (nsFont && ![[nsFont coveredCharacterSet] characterIsMember:c]) {
 	UTF16Char ch = c;
@@ -897,7 +883,8 @@ TkpMeasureCharsInContext(
         /* The call to CTTypesetterSuggestClusterBreak above will always
            return at least one character regardless of whether it exceeded
            it or not.  Clean that up now. */
-	  while (width > maxWidth && !(flags & TK_PARTIAL_OK) && index > start+(flags & TK_AT_LEAST_ONE)) {
+	while (width > maxWidth && !(flags & TK_PARTIAL_OK)
+		&& index > start+(flags & TK_AT_LEAST_ONE)) {
 	    range.length = --index;
 	    line = CTTypesetterCreateLine(typesetter, range);
 	    width = CTLineGetTypographicBounds(line, NULL, NULL, NULL);
@@ -967,6 +954,29 @@ Tk_DrawChars(
 	    0, numBytes, x, y, 0.0);
 }
 
+void
+TkDrawAngledChars(
+    Display *display,		/* Display on which to draw. */
+    Drawable drawable,		/* Window or pixmap in which to draw. */
+    GC gc,			/* Graphics context for drawing characters. */
+    Tk_Font tkfont,		/* Font in which characters will be drawn;
+				 * must be the same as font used in GC. */
+    const char *source,		/* UTF-8 string to be displayed. Need not be
+				 * '\0' terminated. All Tk meta-characters
+				 * (tabs, control characters, and newlines)
+				 * should be stripped out of the string that
+				 * is passed to this function. If they are not
+				 * stripped out, they will be displayed as
+				 * regular printing characters. */
+    int numBytes,		/* Number of bytes in string. */
+    double x, double y,		/* Coordinates at which to place origin of
+				 * string when drawing. */
+    double angle)		/* What angle to put text at, in degrees. */
+{
+    DrawCharsInContext(display, drawable, gc, tkfont, source, numBytes,
+	    0, numBytes, x, y, angle);
+}
+
 /*
  *---------------------------------------------------------------------------
  *
@@ -1079,7 +1089,7 @@ DrawCharsInContext(
     t = CGAffineTransformMake(1.0, 0.0, 0.0, -1.0, 0.0, h);
     if (angle != 0.0) {
 	t = CGAffineTransformTranslate(CGAffineTransformRotate(
-		CGAffineTransformTranslate(t, x, y), angle*M_PI/180.0), -x, -y);
+		CGAffineTransformTranslate(t, x, y), angle*PI/180.0), -x, -y);
     }
     CGContextConcatCTM(context, t);
     CGContextSetTextPosition(context, x, y);
@@ -1177,6 +1187,58 @@ TkMacOSXIsCharacterMissing(
     return 0;
 }
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * TkMacOSXFontDescriptionForNSFontAndNSFontAttributes --
+ *
+ *	Get text description of a font specified by NSFont and attributes.
+ *
+ * Results:
+ *	List object or NULL.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+MODULE_SCOPE Tcl_Obj *
+TkMacOSXFontDescriptionForNSFontAndNSFontAttributes(
+    NSFont *nsFont,
+    NSDictionary *nsAttributes)
+{
+    Tcl_Obj *objv[6];
+    int i = 0;
+    const char *familyName = [[nsFont familyName] UTF8String];
+
+    if (nsFont && familyName) {
+	NSFontTraitMask traits = [[NSFontManager sharedFontManager]
+		traitsOfFont:nsFont];
+	id underline = [nsAttributes objectForKey:
+		NSUnderlineStyleAttributeName];
+	id strikethrough = [nsAttributes objectForKey:
+		NSStrikethroughStyleAttributeName];
+	objv[i++] = Tcl_NewStringObj(familyName, -1);
+	objv[i++] = Tcl_NewIntObj([nsFont pointSize]);
+#define S(s) Tcl_NewStringObj(STRINGIFY(s),(int)(sizeof(STRINGIFY(s))-1))
+	objv[i++] = (traits & NSBoldFontMask)	? S(bold)   : S(normal);
+	objv[i++] = (traits & NSItalicFontMask)	? S(italic) : S(roman);
+	if ([underline respondsToSelector:@selector(intValue)] &&
+		([underline intValue] & (NSUnderlineStyleSingle |
+		NSUnderlineStyleThick | NSUnderlineStyleDouble))) {
+	    objv[i++] = S(underline);
+	}
+	if ([strikethrough respondsToSelector:@selector(intValue)] &&
+		([strikethrough intValue] & (NSUnderlineStyleSingle |
+		NSUnderlineStyleThick | NSUnderlineStyleDouble))) {
+	    objv[i++] = S(overstrike);
+	}
+#undef S
+    }
+    return i ? Tcl_NewListObj(i, objv) : NULL;
+}
+
 /*
  *----------------------------------------------------------------------
  *
