@@ -221,8 +221,8 @@ OappHandler(
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
 
     if (interp &&
-	    Tcl_GetCommandInfo(interp, "::tk::mac::OpenApplication", &dummy)){
-	int code = Tcl_GlobalEval(interp, "::tk::mac::OpenApplication");
+	    Tcl_FindCommand(interp, "::tk::mac::OpenApplication", NULL, 0)){
+	int code = Tcl_EvalEx(interp, "::tk::mac::OpenApplication", -1, TCL_EVAL_GLOBAL);
 	if (code != TCL_OK) {
 	    Tcl_BackgroundException(interp, code);
 	}
@@ -252,14 +252,13 @@ RappHandler(
     AppleEvent *reply,
     SRefCon handlerRefcon)
 {
-    Tcl_CmdInfo dummy;
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
     ProcessSerialNumber thePSN = {0, kCurrentProcess};
     OSStatus err = ChkErr(SetFrontProcess, &thePSN);
 
-    if (interp && Tcl_GetCommandInfo(interp,
-	    "::tk::mac::ReopenApplication", &dummy)) {
-	int code = Tcl_GlobalEval(interp, "::tk::mac::ReopenApplication");
+    if (interp && Tcl_FindCommand(interp,
+	    "::tk::mac::ReopenApplication", NULL, 0)) {
+	int code = Tcl_EvalEx(interp, "::tk::mac::ReopenApplication", -1, TCL_EVAL_GLOBAL);
 	if (code != TCL_OK){
 	    Tcl_BackgroundException(interp, code);
 	}
@@ -294,8 +293,8 @@ PrefsHandler(
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
 
     if (interp &&
-	    Tcl_GetCommandInfo(interp, "::tk::mac::ShowPreferences", &dummy)){
-	int code = Tcl_GlobalEval(interp, "::tk::mac::ShowPreferences");
+	    Tcl_FindCommand(interp, "::tk::mac::ShowPreferences", NULL, 0)){
+	int code = Tcl_EvalEx(interp, "::tk::mac::ShowPreferences", -1, TCL_EVAL_GLOBAL);
 	if (code != TCL_OK) {
 	    Tcl_BackgroundException(interp, code);
 	}
@@ -333,7 +332,6 @@ OdocHandler(
     long count, index;
     AEKeyword keyword;
     Tcl_DString command, pathName;
-    Tcl_CmdInfo dummy;
     int code;
 
     /*
@@ -342,7 +340,7 @@ OdocHandler(
      */
 
     if (!interp ||
-	    !Tcl_GetCommandInfo(interp, "::tk::mac::OpenDocument", &dummy)) {
+	    !Tcl_FindCommand(interp, "::tk::mac::OpenDocument", NULL, 0)) {
 	return noErr;
     }
 
@@ -433,7 +431,7 @@ PrintHandler(
      */
 
     if (!interp ||
-	    !Tcl_GetCommandInfo(interp, "::tk::mac::PrintDocument", &dummy)) {
+	    !Tcl_FindCommand(interp, "::tk::mac::PrintDocument", NULL, 0)) {
 	return noErr;
     }
 
@@ -545,7 +543,7 @@ ScriptHandler(
 
 	    theErr = FSRefToDString(&file, &scriptName);
 	    if (theErr == noErr) {
-		tclErr = Tcl_EvalFile(interp, Tcl_DStringValue(&scriptName));
+		tclErr = Tcl_FSEvalFileEx(interp, Tcl_DStringValue(&scriptName), NULL);
 		Tcl_DStringFree(&scriptName);
 	    } else {
 		sprintf(errString, "AEDoScriptHandler: file not found");
@@ -623,9 +621,8 @@ ReallyKillMe(
     int flags)
 {
     Tcl_Interp *interp = ((KillEvent *) eventPtr)->interp;
-    Tcl_CmdInfo dummy;
-    int quit = Tcl_GetCommandInfo(interp, "::tk::mac::Quit", &dummy);
-    int code = Tcl_GlobalEval(interp, quit ? "::tk::mac::Quit" : "exit");
+    int quit = Tcl_FindCommand(interp, "::tk::mac::Quit", NULL, 0)!=NULL;
+    int code = Tcl_EvalEx(interp, quit ? "::tk::mac::Quit" : "exit", -1, TCL_EVAL_GLOBAL);
 
     if (code != TCL_OK) {
 	/*
