@@ -651,7 +651,7 @@ XConfigureWindow(
  *
  * TkMacOSXUpdateClipRgn --
  *
- *	This function updates the cliping regions for a given window and all of
+ *	This function updates the clipping regions for a given window and all of
  *	its children. Once updated the TK_CLIP_INVALID flag in the subwindow
  *	data structure is unset. The TK_CLIP_INVALID flag should always be
  *	unset before any drawing is attempted.
@@ -742,13 +742,6 @@ TkMacOSXUpdateClipRgn(
 		    kWindowResizableAttribute) {
 		NSWindow *w = TkMacOSXDrawableWindow(winPtr->window);
 
-		if (w) {
-		    bounds = NSRectToCGRect([w _growBoxRect]);
-		    bounds.origin.y = [w contentRectForFrameRect:
-			    [w frame]].size.height - bounds.size.height -
-			    bounds.origin.y;
-		    ChkErr(TkMacOSHIShapeDifferenceWithRect, rgn, &bounds);
-		}
 	    }
 	    macWin->aboveVisRgn = HIShapeCreateCopy(rgn);
 
@@ -825,7 +818,7 @@ TkMacOSXUpdateClipRgn(
  *
  * TkMacOSXVisableClipRgn --
  *
- *	This function returns the Macintosh cliping region for the given
+ *	This function returns the Macintosh clipping region for the given
  *	window. The caller is responsible for disposing of the returned
  *	region via TkDestroyRegion().
  *
@@ -920,7 +913,7 @@ TkMacOSXInvalidateWindow(
 				 * TK_PARENT_WINDOW */
 {
 #ifdef TK_MAC_DEBUG_CLIP_REGIONS
-    TkMacOSXDbgMsg("%s", winPtr->pathName);
+    TkMacOSXDbgMsg("%s", macWin->winPtr->pathName);
 #endif
     if (macWin->flags & TK_CLIP_INVALID) {
 	TkMacOSXUpdateClipRgn(macWin->winPtr);
@@ -1078,7 +1071,7 @@ TkMacOSXGetRootControl(
  *	None.
  *
  * Side effects:
- *	The cliping regions for the window and its children are mark invalid.
+ *	The clipping regions for the window and its children are marked invalid.
  *	(Make sure they are valid before drawing.)
  *
  *----------------------------------------------------------------------
@@ -1097,6 +1090,10 @@ TkMacOSXInvalClipRgns(
      * be marked.
      */
 
+#ifdef TK_MAC_DEBUG_CLIP_REGIONS
+	TkMacOSXDbgMsg("%s", winPtr->pathName);
+#endif
+
     if (!macWin || macWin->flags & TK_CLIP_INVALID) {
 	return;
     }
@@ -1277,7 +1274,7 @@ UpdateOffsets(
  *	Returns a handle to a new pixmap.
  *
  * Side effects:
- *	Allocates a new Macintosh GWorld.
+ *	Allocates a new CGBitmapContext.
  *
  *----------------------------------------------------------------------
  */
@@ -1323,7 +1320,7 @@ Tk_GetPixmap(
  *	None.
  *
  * Side effects:
- *	Deletes the Macintosh GWorld created by Tk_GetPixmap.
+ *	Deletes the CGBitmapContext created by Tk_GetPixmap.
  *
  *----------------------------------------------------------------------
  */
