@@ -138,6 +138,42 @@ namespace eval tk {
             focus -force .focus.e
             destroy .focus
 	}
+
+
+        namespace export imageInit imageFinish imageCleanup imageNames
+        variable ImageNames
+        proc imageInit {} {
+            variable ImageNames
+            if {![info exists ImageNames]} {
+                set ImageNames [lsort [image names]]
+            }
+            imageCleanup
+            if {[lsort [image names]] ne $ImageNames} {
+                return -code error "IMAGE NAMES mismatch: [image names] != $ImageNames"
+            }
+        }
+        proc imageFinish {} {
+            variable ImageNames
+            if {[lsort [image names]] ne $ImageNames} {
+                return -code error "images remaining: [image names] != $ImageNames"
+            }
+            imageCleanup
+        }
+        proc imageCleanup {} {
+            variable ImageNames
+            foreach img [image names] {
+                if {$img ni $ImageNames} {image delete $img}
+            }
+        }
+        proc imageNames {} {
+            variable ImageNames
+            set r {}
+            foreach img [image names] {
+                if {$img ni $ImageNames} {lappend r $img}
+            }
+            return $r
+        }
+
     }
 }
 
@@ -171,7 +207,6 @@ testConstraint testembed     [llength [info commands testembed]]
 testConstraint testfont      [llength [info commands testfont]]
 testConstraint testmakeexist [llength [info commands testmakeexist]]
 testConstraint testmenubar   [llength [info commands testmenubar]]
-testConstraint testmenubar   [llength [info commands testmenubar]]
 testConstraint testmetrics   [llength [info commands testmetrics]]
 testConstraint testobjconfig [llength [info commands testobjconfig]]
 testConstraint testsend      [llength [info commands testsend]]
@@ -182,7 +217,7 @@ testConstraint testwrapper   [llength [info commands testwrapper]]
 # constraint to see what sort of fonts are available
 testConstraint fonts 1
 destroy .e
-entry .e -width 0 -font {Helvetica -12} -bd 1
+entry .e -width 0 -font {Helvetica -12} -bd 1 -highlightthickness 1
 .e insert end a.bcd
 if {([winfo reqwidth .e] != 37) || ([winfo reqheight .e] != 20)} {
     testConstraint fonts 0
@@ -242,7 +277,6 @@ namespace import -force tcltest::removeDirectory
 namespace import -force tcltest::interpreter
 namespace import -force tcltest::testsDirectory
 namespace import -force tcltest::cleanupTests
-namespace import -force tcltest::bytestring
 
 deleteWindows
 wm geometry . {}
